@@ -1435,15 +1435,13 @@ initXOSD(void)
 #ifdef HAVE_LIBXOSD
     if ( osd )
     {
-        osd = xosd_init(xstrdup(getConfig("osd_font")),
-                        /* I dunno why, but you must call strdup here... */
-                        xstrdup(getConfig("osd_color")),
-                        atoi(getConfig("osd_timeout")),
-                        strncmp(getConfig("osd_position"),"top",3)?XOSD_bottom:XOSD_top,
-                        atoi(getConfig("osd_offset")), 
-                        3       /* shadow offset */,
-                        3       /* number_lines */ 
-                        );
+      osd = xosd_create(3);
+      xosd_set_font(osd, xstrdup(getConfig("osd_font")));
+      xosd_set_shadow_offset(osd, 3);
+      xosd_set_colour(osd, getConfig("osd_color"));
+      xosd_set_pos(osd, strncmp(getConfig("osd_position"),"top",3)
+		   ?XOSD_bottom:XOSD_top);
+      xosd_set_vertical_offset(osd, atoi(getConfig("osd_offset")));
     }
 #endif
 }
@@ -1608,7 +1606,7 @@ main(int argc, char *argv[])
 
 #ifdef HAVE_LIBXOSD
     if (osd)
-        xosd_uninit(osd);
+      xosd_destroy(osd);
 #endif
     XCloseDisplay(dpy);
     closelog();
